@@ -1,4 +1,4 @@
-use std::{fs, io::Read};
+use std::{fs, io::{Read, Write}};
 
 pub use super::*;
 
@@ -17,11 +17,14 @@ pub fn read_to_end(fname: String) -> Result<Vec<Byte>, String> {
     Ok(buf)
 }
 
-pub fn read_to_routine(fname: String) -> Result<Routine, String> {
-    let vec = match read_to_end(fname) {
-        Ok(ok) => ok.clone(),
-        Err(err) => return Err(err.clone())
+pub fn write_all(fname: String, bytecode: Vec<Byte>) -> Option<String> {
+    let mut fp = match fs::File::open(fname) {
+        Ok(ok) => ok,
+        Err(err) => return Some(format!("{:?}", err))
     };
 
-    Ok(Routine::from(vec))
+    match fp.write_all(&bytecode) {
+        Ok(_ok) => return None,
+        Err(err) => return Some(format!("{:?}", err))
+    };
 }
